@@ -71,9 +71,9 @@ _ibus_marshal_VOID__STRING_INT (GClosure     *closure,
                                                  gpointer     arg_1,
                                                  gint         arg_2,
                                                  gpointer     data2);
-  register GMarshalFunc_VOID__STRING_INT callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__STRING_INT callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 3);
 
@@ -108,9 +108,9 @@ _ibus_marshal_VOID__STRING_UINT (GClosure     *closure,
                                                   gpointer     arg_1,
                                                   guint        arg_2,
                                                   gpointer     data2);
-  register GMarshalFunc_VOID__STRING_UINT callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__STRING_UINT callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 3);
 
@@ -144,9 +144,9 @@ _ibus_marshal_BOOLEAN__POINTER (GClosure     *closure,
   typedef gboolean (*GMarshalFunc_BOOLEAN__POINTER) (gpointer     data1,
                                                      gpointer     arg_1,
                                                      gpointer     data2);
-  register GMarshalFunc_BOOLEAN__POINTER callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_BOOLEAN__POINTER callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
   gboolean v_return;
 
   g_return_if_fail (return_value != NULL);
@@ -184,9 +184,9 @@ _ibus_marshal_BOOLEAN__POINTER_POINTER (GClosure     *closure,
                                                              gpointer     arg_1,
                                                              gpointer     arg_2,
                                                              gpointer     data2);
-  register GMarshalFunc_BOOLEAN__POINTER_POINTER callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_BOOLEAN__POINTER_POINTER callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
   gboolean v_return;
 
   g_return_if_fail (return_value != NULL);
@@ -225,9 +225,9 @@ _ibus_marshal_BOOLEAN__UINT_UINT (GClosure     *closure,
                                                        guint        arg_1,
                                                        guint        arg_2,
                                                        gpointer     data2);
-  register GMarshalFunc_BOOLEAN__UINT_UINT callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_BOOLEAN__UINT_UINT callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
   gboolean v_return;
 
   g_return_if_fail (return_value != NULL);
@@ -267,9 +267,9 @@ _ibus_marshal_BOOLEAN__UINT_UINT_UINT (GClosure     *closure,
                                                             guint        arg_2,
                                                             guint        arg_3,
                                                             gpointer     data2);
-  register GMarshalFunc_BOOLEAN__UINT_UINT_UINT callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_BOOLEAN__UINT_UINT_UINT callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
   gboolean v_return;
 
   g_return_if_fail (return_value != NULL);
@@ -308,9 +308,9 @@ _ibus_marshal_BOOLEAN__ULONG (GClosure     *closure,
   typedef gboolean (*GMarshalFunc_BOOLEAN__ULONG) (gpointer     data1,
                                                    gulong       arg_1,
                                                    gpointer     data2);
-  register GMarshalFunc_BOOLEAN__ULONG callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_BOOLEAN__ULONG callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
   gboolean v_return;
 
   g_return_if_fail (return_value != NULL);
@@ -350,9 +350,9 @@ _ibus_marshal_VOID__INT_INT_INT_INT (GClosure     *closure,
                                                       gint         arg_3,
                                                       gint         arg_4,
                                                       gpointer     data2);
-  register GMarshalFunc_VOID__INT_INT_INT_INT callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__INT_INT_INT_INT callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 5);
 
@@ -389,9 +389,9 @@ _ibus_marshal_VOID__UINT_UINT (GClosure     *closure,
                                                 guint        arg_1,
                                                 guint        arg_2,
                                                 gpointer     data2);
-  register GMarshalFunc_VOID__UINT_UINT callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__UINT_UINT callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 3);
 
@@ -426,9 +426,9 @@ _ibus_marshal_VOID__INT_UINT (GClosure     *closure,
                                                gint         arg_1,
                                                guint        arg_2,
                                                gpointer     data2);
-  register GMarshalFunc_VOID__INT_UINT callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__INT_UINT callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 3);
 
@@ -464,9 +464,9 @@ _ibus_marshal_VOID__UINT_UINT_UINT (GClosure     *closure,
                                                      guint        arg_2,
                                                      guint        arg_3,
                                                      gpointer     data2);
-  register GMarshalFunc_VOID__UINT_UINT_UINT callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__UINT_UINT_UINT callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 4);
 
@@ -503,9 +503,9 @@ _ibus_marshal_VOID__OBJECT_UINT_BOOLEAN (GClosure     *closure,
                                                           guint        arg_2,
                                                           gboolean     arg_3,
                                                           gpointer     data2);
-  register GMarshalFunc_VOID__OBJECT_UINT_BOOLEAN callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__OBJECT_UINT_BOOLEAN callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 4);
 
@@ -543,9 +543,9 @@ _ibus_marshal_VOID__OBJECT_UINT_BOOLEAN_UINT (GClosure     *closure,
                                                                gboolean     arg_3,
                                                                guint        arg_4,
                                                                gpointer     data2);
-  register GMarshalFunc_VOID__OBJECT_UINT_BOOLEAN_UINT callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__OBJECT_UINT_BOOLEAN_UINT callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 5);
 
@@ -583,9 +583,9 @@ _ibus_marshal_VOID__OBJECT_UINT_UINT (GClosure     *closure,
                                                        guint        arg_2,
                                                        guint        arg_3,
                                                        gpointer     data2);
-  register GMarshalFunc_VOID__OBJECT_UINT_UINT callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__OBJECT_UINT_UINT callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 4);
 
@@ -621,9 +621,9 @@ _ibus_marshal_VOID__OBJECT_BOOLEAN (GClosure     *closure,
                                                      gpointer     arg_1,
                                                      gboolean     arg_2,
                                                      gpointer     data2);
-  register GMarshalFunc_VOID__OBJECT_BOOLEAN callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__OBJECT_BOOLEAN callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 3);
 
@@ -658,9 +658,9 @@ _ibus_marshal_VOID__BOXED_BOOLEAN (GClosure     *closure,
                                                     gpointer     arg_1,
                                                     gboolean     arg_2,
                                                     gpointer     data2);
-  register GMarshalFunc_VOID__BOXED_BOOLEAN callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__BOXED_BOOLEAN callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 3);
 
@@ -698,9 +698,9 @@ _ibus_marshal_VOID__STRING_STRING_VARIANT (GClosure     *closure,
                                                             gpointer     arg_2,
                                                             gpointer     arg_3,
                                                             gpointer     data2);
-  register GMarshalFunc_VOID__STRING_STRING_VARIANT callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__STRING_STRING_VARIANT callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 4);
 
@@ -737,9 +737,9 @@ _ibus_marshal_VOID__STRING_STRING_STRING (GClosure     *closure,
                                                            gpointer     arg_2,
                                                            gpointer     arg_3,
                                                            gpointer     data2);
-  register GMarshalFunc_VOID__STRING_STRING_STRING callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__STRING_STRING_STRING callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 4);
 
@@ -779,9 +779,9 @@ _ibus_marshal_VOID__POINTER_UINT (GClosure     *closure,
                                                    gpointer     arg_1,
                                                    guint        arg_2,
                                                    gpointer     data2);
-  register GMarshalFunc_VOID__POINTER_UINT callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__POINTER_UINT callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 3);
 
@@ -815,9 +815,9 @@ _ibus_marshal_OBJECT__STRING (GClosure     *closure,
   typedef GObject* (*GMarshalFunc_OBJECT__STRING) (gpointer     data1,
                                                    gpointer     arg_1,
                                                    gpointer     data2);
-  register GMarshalFunc_OBJECT__STRING callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_OBJECT__STRING callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
   GObject* v_return;
 
   g_return_if_fail (return_value != NULL);
